@@ -515,6 +515,13 @@ def add_round_float(a, b, digit=4):
 def sub_round_float(a, b, digit=4):
     return float(decimalRound(sub(a, b), digit))
 
+def amt_divide(amt, num):
+    '''计算金额及除不尽的余数'''
+    if float(amt) <= 0 or int(num) <= 0: return 0.0, 0.0
+    uprice = div_round(amt, num)
+    indiv = sub(amt, mut(uprice, num))
+    return uprice, indiv
+
 def windows_print_file(fp,printer):
     try:
         import win32api
